# Trying to Contribute?

Thank you for trying to contribute to the project! We appreciate your enthusiasm!
We do not have lots of rules for contributing, just 2:
- Have Patience:
  - Maintainers may not be available all the time.
- "Useless" Contributions
   - Usually, we do not accept contributions which do not add something, so if you just added one character to one file, that is classified as "Useless"

